package safehome;

import safehome.device.DeviceControlPanelAbstract;

/*
 * CLASS NAME : ControlPanel 
 * DESCRIPTION
 * 		A simple implementation of the abstract class
 * 		All implemented abstract methods has small functionality to show it is working well
 * 		All APIs that provided from super class is tested by buttons
 * PRECONDITION : From main dialog, "Control Panel" button was chosen
 * PARAMETER : none
 * RETURN VALUE : none
 * USAGE : click the numeric buttons
 * EXAMPLE : click the button 1 to test its functionality
 * POSTCONDITION : none
 * NOTES : If possible, click all buttons to test all functionality
 */ 
/**
 * This class is a simple implementation of the abstract 
 * class <code>{@link DeviceControlPanelAbstract}</code>. All abstract methods are 
 * implemented simply to show that each button is working well.
 * <p>
 * 
 *        
 * @author cs550 TA
 * @see safehome.device.DeviceControlPanelAbstract
 */
public class ControlPanel extends DeviceControlPanelAbstract
{
	/*
	 * NAME : ControlPanel (constructor)
	 * DESCRIPTION
	 * 		Initiate the short messages
	 * PRECONDITION
	 * 		The main instantiates MainDemo class and MainDemo instantiates this class
	 * 		in consecutively
	 * PARAMETER : none
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE : none
	 * POSTCONDITION : The control panel is ready
	 * NOTES : none
	 */ 
	/**
	 * Constructs a control panel frame.
	 * <p>
	 * Pre-condition: None.
	 * <p>
	 * Post-condition: The control panel frame is ready. It is initially invisible.
	 * @see safehome.device.DeviceControlPanelAbstract#DeviceControlPanelAbstract().
	 */
	
	public ControlPanel()
	{
		super();
		setDisplayShortMessage1("        Starting system");
		setDisplayShortMessage2("        please wait...");
	}
	
	/*
	 * NAME : button1
	 * DESCRIPTION
	 * 		set display security zone number to 1
	 * 		turn on the power LED
	 * 		display short message of what key is pressed
	 * PRECONDITION : the control panel is ready and poped up to user
	 * PARAMETER : none
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE : none
	 * POSTCONDITION : The control panel is ready and slightly changed in view
	 * NOTES : none
	 */ 
	/** 
	 * Specifies the action which occurs when button 1 is pressed. 
	 * It sets security zone number to 1, turns on the power LED and changes the message to 
	 * <p>
	 * Key 1 pressed<br>On Button
	 * <p>  
	 * Pre-condition: The control panel is ready and visible to the user.
	 * <p>
	 * Post-condition: Security zone number is changed to 1, power LED is turned on and
	 * the message is changed to 
	 * <p>
	 * Key 1 pressed<br>On Button<p>  
	 * 
	 * @see safehome.device.DeviceControlPanelAbstract#button1()
	 */
	public void button1()
	{
		// example running (key is active)
		setDisplaySecurityZone(1);
		setLedPowered(true);
		setDisplayShortMessage1("    key 1 pressed");
		setDisplayShortMessage2("    On Button");
		// To do
		//
	}
	
	/*
	 * NAME : button2
	 * DESCRIPTION
	 * 		set display security zone number to 2
	 * 		turn off all LED and toggle messages
	 * 		display short message of what key is pressed
	 * PRECONDITION : the control panel is ready and poped up to user
	 * PARAMETER : none
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE : none
	 * POSTCONDITION : The control panel is ready and slightly changed in view
	 * NOTES : none
	 */ 
	/** 
	 * Specifies the action which occurs when button 2 is pressed. 
	 * It sets security zone number to 2, turns off all the LEDs, clears 
	 * status display(Away, Stay, Not Ready) and changes the message to 
	 * <p>
	 * Key 2 pressed<br>Off Button
	 * <p>  
	 * Pre-condition: The control panel is ready and visible to the user.
	 * <p>
	 * Post-condition: Security zone number is changed to 2, all the LEDs are turned off,
	 * the status display is clear and the message is changed to 
	 * <p>
	 * Key 2 pressed<br>Off Button<p>  
	 * 
	 * @see safehome.device.DeviceControlPanelAbstract#button2()
	 */
	public void button2()
	{
		// example running (key is active)
		setDisplaySecurityZone(2);
		setDisplayAway(false);
		setDisplayStay(false);
		setDisplayNotReady(false);
		setDisplayShortMessage1("    key 2 pressed");
		setDisplayShortMessage2("    Off Button");
		setLedArmed(false);
		setLedPowered(false);
		// To do
		//
	}
	
	/*
	 * NAME : button3
	 * DESCRIPTION
	 * 		set display security zone number to 3
	 * 		turn off the armed LED and toggle messages
	 * 		display short message of what key is pressed
	 * PRECONDITION : the control panel is ready and poped up to user
	 * PARAMETER : none
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE : none
	 * POSTCONDITION : The control panel is ready and slightly changed in view
	 * NOTES : none
	 */ 
	/** 
	 * Specifies the action which occurs when button 3 is pressed. 
	 * It sets security zone number to 3, turns off the 'armed' LED, clears
	 * status display(Away, Stay, Not Ready) and changes the message to 
	 * <p>
	 * Key 3 pressed<br>Reset Button
	 * <p>  
	 * Pre-condition: The control panel is ready and visible to the user.
	 * <p>
	 * Post-condition: Security zone number is changed to 3, the 'armed' LED is turned off, 
	 * the status display is clear and the message is changed to 
	 * <p>
	 * Key 3 pressed<br>Reset Button<p>  
	 * 
	 * @see safehome.device.DeviceControlPanelAbstract#button3()
	 */
	public void button3()
	{
		// example running (key is active)
		setDisplaySecurityZone(3);
		setDisplayAway(false);
		setDisplayStay(false);
		setDisplayNotReady(false);
		setLedArmed(false);
		setDisplayShortMessage1("    key 3 pressed");
		setDisplayShortMessage2("    Reset Button");
		// To do
		//
	}
	
	/*
	 * NAME : button4
	 * DESCRIPTION
	 * 		set display security zone number to 4
	 * 		display short message of what key is pressed
	 * PRECONDITION : the control panel is ready and poped up to user
	 * PARAMETER : none
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE : none
	 * POSTCONDITION : The control panel is ready and slightly changed in view
	 * NOTES : none
	 */ 
	/* (non-Javadoc)
	 * @see safehome.device.DeviceControlPanelAbstract#button4()
	 */
	/** 
	 * Specifies the action which occurs when button 4 is pressed. 
	 * It sets security zone number to 4 and changes the message to 
	 * <p>
	 * Key 4 pressed<br>
	 * <p>  
	 * Pre-condition: The control panel is ready and visible to the user.
	 * <p>
	 * Post-condition: Security zone number is changed to 4 and
	 * the message is changed to 
	 * <p>
	 * Key 4 pressed<p>  
	 * 
	 * @see safehome.device.DeviceControlPanelAbstract#button4()
	 */
	public void button4()
	{
		// example running (key is active)
		setDisplaySecurityZone(4);
		setDisplayShortMessage1("    key 4 pressed");
		setDisplayShortMessage2("    Zone Button");
		// To do
		//
	}

	/*
	 * NAME : button5
	 * DESCRIPTION
	 * 		set display security zone number to 5
	 * 		display short message of what key is pressed
	 * PRECONDITION : the control panel is ready and poped up to user
	 * PARAMETER : none
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE : none
	 * POSTCONDITION : The control panel is ready and slightly changed in view
	 * NOTES : none
	 */ 
	/* (non-Javadoc)
	 * @see safehome.device.DeviceControlPanelAbstract#button5()
	 */
	/** 
	 * Specifies the action which occurs when button 5 is pressed. 
	 * It sets security zone number to 5 and changes the message to 
	 * <p>
	 * Key 5 pressed<br>
	 * <p>  
	 * Pre-condition: The control panel is ready and visible to the user.
	 * <p>
	 * Post-condition: Security zone number is changed to 5 and
	 * the message is changed to 
	 * <p>
	 * Key 5 pressed<p>  
	 * 
	 * @see safehome.device.DeviceControlPanelAbstract#button5()
	 */
	public void button5()
	{
		// example running (key is active)
		setDisplaySecurityZone(5);
		setDisplayShortMessage1("    key 5 pressed");
		setDisplayShortMessage2("");
		// To do
		//
	}

	/*
	 * NAME : button6
	 * DESCRIPTION
	 * 		set display security zone number to 6
	 * 		display short message of what key is pressed
	 * PRECONDITION : the control panel is ready and poped up to user
	 * PARAMETER : none
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE : none
	 * POSTCONDITION : The control panel is ready and slightly changed in view
	 * NOTES : none
	 */ 
	/* (non-Javadoc)
	 * @see safehome.device.DeviceControlPanelAbstract#button6()
	 */
	/** 
	 * Specifies the action which occurs when button 6 is pressed. 
	 * It sets security zone number to 6 and changes the message to 
	 * <p>
	 * Key 6 pressed<br>
	 * <p>  
	 * Pre-condition: The control panel is ready and visible to the user.
	 * <p>
	 * Post-condition: Security zone number is changed to 6 and
	 * the message is changed to 
	 * <p>
	 * Key 6 pressed<p>  
	 * 
	 * @see safehome.device.DeviceControlPanelAbstract#button6()
	 */
	public void button6()
	{
		// example running (key is active)
		setDisplaySecurityZone(6);
		setDisplayShortMessage1("    key 6 pressed");
		setDisplayShortMessage2("");
		// To do
		//
	}
	
	/*
	 * NAME : button7
	 * DESCRIPTION
	 * 		set display security zone number to 7
	 * 		turn on armed LED and away
	 * 		display short message of what key is pressed
	 * PRECONDITION : the control panel is ready and poped up to user
	 * PARAMETER : none
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE : none
	 * POSTCONDITION : The control panel is ready and slightly changed in view
	 * NOTES : none
	 */ 
	/* (non-Javadoc)
	 * @see safehome.device.DeviceControlPanelAbstract#button7()
	 */
	/** 
	 * Specifies the action which occurs when button 7 is pressed. 
	 * It sets security zone number to 7 , turns on the 'Away' LED, shows 
	 * 'Away' status on the display and changes the message to 
	 * <p>
	 * Key 7 pressed<br>
	 * Away Button
	 * <p>  
	 * Pre-condition: The control panel is ready and visible to the user.
	 * <p>
	 * Post-condition: Security zone number is changed to 7, 'armed' LED is turned on
	 * 'Away' status is shown on the display and the message is changed to 
	 * <p>
	 * Key 7 pressed<br>
	 * Away Button<p>
	 * 
	 * @see safehome.device.DeviceControlPanelAbstract#button7()
	 */
	public void button7()
	{
		// example running (key is active)
		setDisplaySecurityZone(7);
		setDisplayAway(true);
		setLedArmed(true);
		setDisplayShortMessage1("    key 7 pressed");
		setDisplayShortMessage2("    Away Button");
		// To do
		//
	}
	
	/*
	 * NAME : button8
	 * DESCRIPTION
	 * 		set display security zone number to 8
	 * 		turn on armed LED and stay
	 * 		display short message of what key is pressed
	 * PRECONDITION : the control panel is ready and poped up to user
	 * PARAMETER : none
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE : none
	 * POSTCONDITION : The control panel is ready and slightly changed in view
	 * NOTES : none
	 */ 
	/* (non-Javadoc)
	 * @see safehome.device.DeviceControlPanelAbstract#button8()
	 */
	/** 
	 * Specifies the action which occurs when button 8 is pressed. 
	 * It sets security zone number to 8 , turns on the 'Stay' LED, shows 
	 * 'Stay' status on the display and changes the message to 
	 * <p>
	 * Key 8 pressed<br>
	 * Stay Button
	 * <p>  
	 * Pre-condition: The control panel is ready and visible to the user.
	 * <p>
	 * Post-condition: Security zone number is changed to 8, 'armed' LED is turned on
	 * 'Stay' status is shown on the display and the message is changed to 
	 * <p>
	 * Key 8 pressed<br>
	 * Stay Button<p>
	 * 
	 * @see safehome.device.DeviceControlPanelAbstract#button8()
	 */
	public void button8()
	{
		// example running (key is active)
		setDisplaySecurityZone(8);
		setDisplayStay(true);
		setLedArmed(false);
		setDisplayShortMessage1("    key 8 pressed");
		setDisplayShortMessage2("    Stay Button");
		// To do
		//
	}

	/*
	 * NAME : button9
	 * DESCRIPTION
	 * 		set display security zone number to 9
	 * 		turn on not ready
	 * 		display short message of what key is pressed
	 * PRECONDITION : the control panel is ready and poped up to user
	 * PARAMETER : none
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE : none
	 * POSTCONDITION : The control panel is ready and slightly changed in view
	 * NOTES : none
	 */ 
	/* (non-Javadoc)
	 * @see safehome.device.DeviceControlPanelAbstract#button9()
	 */
	/** 
	 * Specifies the action which occurs when button 9 is pressed. 
	 * It sets security zone number to 9, shows 'Stay' status on 
	 * the display and changes the message to 
	 * <p>
	 * Key 9 pressed<br>
	 * Code Button
	 * <p>  
	 * Pre-condition: The control panel is ready and visible to the user.
	 * <p>
	 * Post-condition: Security zone number is changed to 9, 
	 * 'Not Ready' status is shown on the display and the message is changed to 
	 * <p>
	 * Key 9 pressed<br>
	 * Code Button<p>
	 * 
	 * @see safehome.device.DeviceControlPanelAbstract#button9()
	 */
	public void button9()
	{
		// example running (key is active)
		//JOptionPane.showMessageDialog(this, "key 9 pressed");
		setDisplaySecurityZone(9);
		setDisplayNotReady(true);
		setDisplayShortMessage1("    key 9 pressed");
		setDisplayShortMessage2("    Code Button");
		// To do
		//
	}
	
	/*
	 * NAME : buttonStar
	 * DESCRIPTION
	 * 		set display security zone number to 10
	 * 		display short message of what key is pressed
	 * PRECONDITION : the control panel is ready and poped up to user
	 * PARAMETER : none
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE : none
	 * POSTCONDITION : The control panel is ready and slightly changed in view
	 * NOTES : none
	 */ 
	/* (non-Javadoc)
	 * @see safehome.device.DeviceControlPanelAbstract#buttonStar()
	 */
	/** 
	 * Specifies the action which occurs when button * is pressed. 
	 * It sets security zone number to 10 and changes the message to 
	 * <p>
	 * Key * pressed<br>
	 * Panic Button
	 * <p>  
	 * Pre-condition: The control panel is ready and visible to the user.
	 * <p>
	 * Post-condition: Security zone number is changed to 10 
	 * and the message is changed to 
	 * <p>
	 * Key * pressed<br>
	 * Panic Button<p>
	 * 
	 * @see safehome.device.DeviceControlPanelAbstract#buttonStar()
	 */
	public void buttonStar()
	{
		// example running (key is active)
		setDisplaySecurityZone(10);
		setDisplayShortMessage1("    key * pressed");
		setDisplayShortMessage2("    Panic Button");
		// To do
		//
	}

	/*
	 * NAME : button0
	 * DESCRIPTION
	 * 		set display security zone number to 11 
	 * 		display short message of what key is pressed
	 * PRECONDITION : the control panel is ready and poped up to user
	 * PARAMETER : none
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE : none
	 * POSTCONDITION : The control panel is ready and slightly changed in view
	 * NOTES : none
	 */ 
	/* (non-Javadoc)
	 * @see safehome.device.DeviceControlPanelAbstract#button0()
	 */
	/** 
	 * Specifies the action which occurs when button 0 is pressed. 
	 * It sets security zone number to 11 and changes the message to 
	 * <p>
	 * Key 0 pressed<br>
	 * <p>  
	 * Pre-condition: The control panel is ready and visible to the user.
	 * <p>
	 * Post-condition: Security zone number is changed to 11 
	 * and the message is changed to 
	 * <p>
	 * Key 0 pressed<br>
	 * <p>
	 * 
	 * @see safehome.device.DeviceControlPanelAbstract#button0()
	 */
	public void button0()
	{
		// example running (key is active)
		setDisplaySecurityZone(11);
		setDisplayShortMessage1("    key 0 pressed");
		setDisplayShortMessage2("");
		// To do
		//
	}

	/*
	 * NAME : buttonSharp
	 * DESCRIPTION
	 * 		set display security zone number to 12
	 * 		display short message of what key is pressed
	 * PRECONDITION : the control panel is ready and poped up to user
	 * PARAMETER : none
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE : none
	 * POSTCONDITION : The control panel is ready and slightly changed in view
	 * NOTES : none
	 */ 
	/* (non-Javadoc)
	 * @see safehome.device.DeviceControlPanelAbstract#buttonSharp()
	 */
	/** 
	 * Specifies the action which occurs when button # is pressed. 
	 * It sets security zone number to 12 and changes the message to 
	 * <p>
	 * Key # pressed<br>
	 * Panic Button
	 * <p>  
	 * Pre-condition: The control panel is ready and visible to the user.
	 * <p>
	 * Post-condition: Security zone number is changed to 12 
	 * and the message is changed to 
	 * <p>
	 * Key # pressed<br>
	 * Panic Button
	 * <p>
	 * 
	 * @see safehome.device.DeviceControlPanelAbstract#buttonSharp()
	 */
	public void buttonSharp()
	{
		// example running (key is active)
		setDisplaySecurityZone(12);
		setDisplayShortMessage1("    key # pressed");
		setDisplayShortMessage2("    Panic Button");
		// To do
		//
	}
	
	/*
	 * meaningless member variable in this application
	 * prevent java compiler warning message
	 */
	static final long serialVersionUID = 1943342;
}
