package safehome;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;



/*
 * CLASS NAME : MainDemo 
 * DESCRIPTION
 * 		A main dialog of whole demo program
 * 		It shows three buttons to enter three test cases 
 * 		 - Control panel test
 * 		 - Sensor test
 * 		 - Camera test
 * PRECONDITION : The program is executed initially
 * PARAMETER : none
 * RETURN VALUE : none
 * USAGE : click on the button
 * EXAMPLE : click the control panel test button to pop up control panel test dialog
 * POSTCONDITION : any one dialog of the test cases are pop up
 * NOTES : Click any button to proceed exact test case
 */  


/**
 * This class shows a main dialog of a whole demo program.
 * When a user runs <code>MainDemo</code> class, <code>MainDemo</code> shows three buttons, 
 * Control Panel/Sensor/Camera, and a Sensor Test window. A user can test each device by 
 * selecting a button.
 * @author cs550 TA
 *
 */
public class MainDemo extends JFrame implements ActionListener 
{
	// instance of three test cases


	private ControlPanel controlPanel;
	private SensorTest sensorTest;
	private CameraTest cameraTest;
	
	

	/**
	 * Runs a simple demo program. 
	 * @param args command line arguments are ignored.
	 */
	public static void main(String[] args)
	{
		MainDemo safeHome = new MainDemo();
		safeHome.setVisible(true);
	}
	
	/*
	 * NAME : MainDemo (constructor) 
	 * DESCRIPTION
	 * 		make layout of main page of this demo program
	 * 		place three buttons - "Control Panel", "sensor", "Camera"
	 * PRECONDITION : The main instantiates MainDemo class
	 * PARAMETER : none
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE : none
	 * POSTCONDITION : The layout of this dialog is made
	 * NOTES : none
	 */  
	/**
	 * Constructs a <code>MainDemo</code> frame with three buttons,
	 * "Control Panel", "Sensor", "Camera". It is initially invisible.
	 * <p>
	 * Pre-condition: None 
	 * <p>
	 * Post-condition: The frame of <code>MainDemo</code> dialog is constructed.   
	 */
	private MainDemo() 
	{
		super("Hardware Device Demo");
		controlPanel = new ControlPanel();
		sensorTest = new SensorTest();
		cameraTest = new CameraTest();
		setSize(400, 215);
		getContentPane().setLayout(null);
		setResizable(false);

		// Terminate the program when the MainDemo dialog is closed
		addWindowListener
		(
				new WindowAdapter()
				{
					public void windowClosing(WindowEvent e)
					{
						System.exit(0);
					}
				}
		);
		
		// make buttons
		JButton ControlPanel = new JButton("Control Panel");
		ControlPanel.addActionListener(this);
		
		JButton SensorTest = new JButton("Sensor");
		SensorTest.addActionListener(this);
		
		JButton Camera = new JButton("Camera");
		Camera.addActionListener(this);
		
		// attach buttons to dialog
		JPanel displayPanel = new JPanel(new GridLayout(3, 1));
		displayPanel.add(ControlPanel);
		displayPanel.add(SensorTest);
		displayPanel.add(Camera);
		displayPanel.setBounds(15, 15, 360, 150);
		getContentPane().add(displayPanel);
	}

	/*
	 * NAME : actionPerformed
	 * DESCRIPTION
	 * 		This function is the action listener(call back function) of three buttons
	 * 		Each button pops up its test dialog
	 * PRECONDITION : User click on any button
	 * PARAMETER : event - ActionEvent that carrying what button was pressed
	 * RETURN VALUE : none
	 * USAGE : none
	 * EXAMPLE
	 * 		If Control Panel button is clicked by user, 
	 * 		the parameter event.getActionCommand() equals "Control Panel"
	 * POSTCONDITION : any one dialog of the test cases are pop up
	 * NOTES : none
	 */  
	/** 
	 * Invoked when an action occurs. When a "Control Panel" button is pressed, 
	 * the demo program shows a control panel dialog. When a "Sensor" or "Camera" button is pressed, 
	 * the demo program shows a sensor test dialog or a camera test dialog accordingly. Otherwise, it does 
	 * no operation. 
	 * <p>
	 * Pre-condition: A user clicks on one of three buttons "Control Panel", "Sensor" and "Camera"
	 * <p>
	 * Post-condition: The corresponding dialog of the test cases is pop up.
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent event)
	{
		if((event.getActionCommand().equals("Control Panel")))
		{
			controlPanel.setVisible(true);
		}
		else if((event.getActionCommand().equals("Sensor")))
		{
			sensorTest.setVisible(true);
		}
		else if((event.getActionCommand().equals("Camera")))
		{
			cameraTest.setVisible(true);
		}
	}
	
	/*
	 * meaningless member variable in this application
	 * prevent java compiler warning message
	 */

	static final long serialVersionUID = 1876534;
}


